@@ -1,6 +1,6 @@
+use super::font::FontArc;
 use super::layout::TextArea;
 use super::style::{Margin, Position, Style};
-use ab_glyph::FontArc;
 use image::{ImageBuffer, Rgba};
 use std::ops::Range;
 
@@ -29,7 +29,7 @@ impl Element {
 }
 
 #[derive(Debug, Default)]
-pub struct Rect {
+pub(super) struct Rect {
     pub(super) x: u32,
     pub(super) y: u32,
     pub(super) width: u32,
@@ -48,7 +48,7 @@ impl Rect {
 }
 
 #[derive(Debug)]
-pub struct Img {
+pub(super) struct Img {
     pub(super) buf: ImageBuffer<Rgba<u8>, Vec<u8>>,
     pub(super) rect: Rect,
     pub(super) style: Style,
@@ -61,19 +61,19 @@ impl Img {
 }
 
 #[derive(Debug)]
-pub struct Line {
+pub(super) struct Fragment {
     pub(super) range: Range<usize>,
     pub(super) rect: Rect,
 }
 
-impl Line {
+impl Fragment {
     pub fn new(range: Range<usize>, rect: Rect) -> Self {
-        Line { range, rect }
+        Fragment { range, rect }
     }
 }
 
 #[derive(Debug, Default)]
-pub struct LineMetrics {
+pub(super) struct LineMetrics {
     pub total_height: u32,
     pub max_line_height: f32,
     pub max_line_width: f32,
@@ -90,10 +90,10 @@ impl LineMetrics {
 }
 
 #[derive(Debug)]
-pub struct Text {
+pub(super) struct Text {
     pub(super) text: String,
     pub(super) metrics: LineMetrics,
-    pub(super) lines: Vec<Line>,
+    pub(super) fragments: Vec<Fragment>,
     pub(super) style: Style,
     // TODO: optimize static lifetime
     pub(super) font: Option<FontArc>,
@@ -103,7 +103,7 @@ pub struct Text {
 impl Text {
     pub fn new(
         text: String,
-        lines: Vec<Line>,
+        fragments: Vec<Fragment>,
         metrics: LineMetrics,
         style: Style,
         font: Option<FontArc>,
@@ -111,7 +111,7 @@ impl Text {
     ) -> Self {
         Text {
             text,
-            lines,
+            fragments,
             metrics,
             style,
             font,
