@@ -20,7 +20,7 @@
 //!             justify_content: style::JustifyContent::Center,
 //!             ..style::WindowStyle::default()
 //!         },
-//!         include_bytes!("../../examples/assets/og_template.png"),
+//!         include_bytes!("../../assets/og_template.png"),
 //!         ImageInputFormat::Png,
 //!     )?;
 //!
@@ -40,7 +40,7 @@
 //!         Some(font),
 //!     )?;
 //!
-//!     let out_dir = "../examples/assets";
+//!     let out_dir = "../examples";
 //!     let out_filename = "output_background_image.png";
 //!
 //!     writer.generate(Path::new(&format!("{}/{}", out_dir, out_filename)))?;
@@ -52,7 +52,7 @@
 //! You can also create custom image like bellow.
 //!
 //! ```rust
-//! use og_image_writer::{style, writer::OGImageWriter, TextArea, font::FontContext};
+//! use og_image_writer::{style, writer::OGImageWriter, TextArea, font_context::FontContext};
 //! use std::path::Path;
 //!
 //! fn main() -> anyhow::Result<()> {
@@ -110,8 +110,8 @@
 //!        Some(Vec::from(include_bytes!("../../fonts/OpenSansCondensed-Light.ttf") as &[u8])),
 //!    )?;
 //!
-//!    let out_dir = "../examples/assets";
-//!    let out_filename = "font_context.png";
+//!    let out_dir = "../examples";
+//!    let out_filename = "output_font_context.png";
 //!
 //!    writer.generate(Path::new(&format!("{}/{}", out_dir, out_filename)))?;
 //!
@@ -123,7 +123,7 @@
 //!
 
 pub mod element;
-pub mod font;
+pub mod font_context;
 pub mod img;
 pub mod style;
 pub mod writer;
@@ -134,6 +134,8 @@ pub use layout::TextArea;
 mod char;
 mod context;
 mod error;
+mod font;
+mod font_trait;
 mod glyph;
 mod layout;
 mod line_breaker;
