@@ -167,6 +167,8 @@ impl OGImageWriter {
             }
         }
 
+        self.font_context.clear();
+
         Ok(())
     }
 
@@ -299,7 +301,7 @@ impl OGImageWriter {
                                     Some(font) => render_text(
                                         text,
                                         &mut range,
-                                        font,
+                                        &**font,
                                         &mut self.context,
                                         &mut current_width,
                                         style,
@@ -364,7 +366,7 @@ impl OGImageWriter {
                                     render_text(
                                         text,
                                         &mut range,
-                                        font,
+                                        &**font,
                                         &mut self.context,
                                         &mut current_width,
                                         style,
